# mermaid help

* [Flowchart](https://mermaid.js.org/syntax/flowchart.html)
* [Sequence Diagram](https://mermaid.js.org/syntax/sequenceDiagram.html)
* [Class Diagram](https://mermaid.js.org/syntax/classDiagram.html)
* [State Diagram](https://mermaid.js.org/syntax/stateDiagram.html)
* [Entity Relationship Diagram](https://mermaid.js.org/syntax/entityRelationshipDiagram.html)
* [User Journey](https://mermaid.js.org/syntax/userJourney.html)
* [Gantt](https://mermaid.js.org/syntax/gantt.html)
* [Pie Chart](https://mermaid.js.org/syntax/pie.html)
* [Requirement Diagram](https://mermaid.js.org/syntax/requirementDiagram.html)
* [Gitgraph (Git) Diagram 🔥](https://mermaid.js.org/syntax/gitgraph.html)
* [C4C Diagram (Context) Diagram 🦺⚠️](https://mermaid.js.org/syntax/c4c.html)
* [Mindmaps 🔥](https://mermaid.js.org/syntax/mindmap.html)
* [Other Examples](https://mermaid.js.org/syntax/examples.html)